.. _utility-functions:

=================
Utility functions
=================

`qp.utils.array`: Array utility functions
=========================================

.. automodule:: qp.utils.array
    :members:
    :undoc-members:

`qp.utils.conversion`: Conversion utility functions
===================================================
       
.. automodule:: qp.utils.conversion
    :members:
    :undoc-members:

`qp.utils.dictionary`: Multi-level dictionary manipulation
==========================================================

.. automodule:: qp.utils.dictionary
    :members:
    :undoc-members:
       
`qp.utils.interpolation`: PDF evaluation and construction utility functions
===========================================================================

.. automodule:: qp.utils.interpolation
    :members:
    :undoc-members: